/*!
  \file
  \brief Sl^CsO

  \author Satofumi KAMIMURA

  $Id$

  \todo Ctrl ƁA\ȃL[͂ɂĂ̐\ƂH
  \todo lbg[NΐA̎
  \todo IvVA̎
  \todo I閈ɁAʉ炷
  \todo tXN[̂Ƃ́A}EẌړȂΉB
  \todo lexical_cast ̗OEׂ
  \todo H̃j[ڂɁAHACRtƂ
*/

#include "hyakutyping.h"
#include "CommonResources.h"
#include "ResourceDefinition.h"
#include "FirstMenu.h"
#include "SdlVideo.h"

using namespace beego;
using namespace SDL;
//using namespace GL;


static std::string getSaveDirectory(void) {

  std::string savedir = SaveDir;
  if (! savedir.compare(0, 2, "~/")) {
    // "~/" n܂ꍇAϐ HOME Œu
    const char* home = getenv("HOME");
    if (home != NULL) {
      savedir.replace(0, 1, home);
    }
  }

  return savedir;
}


/*!
  \brief C֐
*/
int main(int argc, char *argv[]) {

  // ̏
  bool music_mute = false;

  // !!! lݒǂݏo悤ɕύX
  // !!! lݒAݒȀɕ]XV
  bool fullscreen = false;
  for (int i = 1; i < argc; ++i) {
    if ((! strcmp("-m", argv[i])) || (! strcmp("--mute", argv[i]))) {
      // ~[gݒ
      music_mute = true;

    } else if ((! strcmp("-fs", argv[i])) ||
               (! strcmp("--fullscreen", argv[i]))) {
      // XN[̍ő剻
      fullscreen = true;
    }
  }

  // ʂ̏
  SdlVideo video;
  video.setCaption(PACKAGE_STRING);
  video.setFullscreenMode(fullscreen);
  if (! video.show()) {
    printf("SdlVideo::show(): %s\n", video.what());
    exit(1);
  }

  // f[^̑݃`FbN
  std::string savedir = getSaveDirectory();
  CommonResources* common = CommonResources::getObject(savedir.c_str());
  if (! CommonResources::accessFontData()) {
    // tHgf[^Ȃ΁AI
    // !!! \ȂAtHgf[^soCiɊ܂߂
    exit(1);
  }
  if (! CommonResources::accessMusicData()) {
    music_mute = true;
  }

  // GUI ̏
  common->initializeGui();

  // y̏
  if (! music_mute) {
    common->initializeMusic();
  }

  // j[ʂ̌Ăяo
  FirstMenu menu;
  menu.run();

  return 0;
}
